@@ -373,38 +373,10 @@ def pydt_strftime(dt=None, format='%Y %b %d  %H:%M.%S', accuracy=None, none_str=
 
 	try:
 		return dt.strftime(format)
+
 	except ValueError:
 		_log.exception()
 		return 'strftime() error'
-		#_log.exception('Python cannot strftime() this <datetime>, trying ourselves')
-
-#	if isinstance(dt, pyDT.date):
-#		accuracy = acc_days
-#
-#	if accuracy == acc_days:
-#		return '%04d-%02d-%02d' % (
-#			dt.year,
-#			dt.month,
-#			dt.day
-#		)
-#
-#	if accuracy == acc_minutes:
-#		return '%04d-%02d-%02d %02d:%02d' % (
-#			dt.year,
-#			dt.month,
-#			dt.day,
-#			dt.hour,
-#			dt.minute
-#		)
-#
-#	return '%04d-%02d-%02d %02d:%02d:%02d' % (
-#		dt.year,
-#		dt.month,
-#		dt.day,
-#		dt.hour,
-#		dt.minute,
-#		dt.second
-#	)
 
 #---------------------------------------------------------------------------
 def pydt_add(dt, years=0, months=0, weeks=0, days=0, hours=0, minutes=0, seconds=0, milliseconds=0, microseconds=0):
@@ -675,10 +647,11 @@ def format_interval_medically(interval=None):
 	This isn't mathematically correct but close enough for display.
 	"""
 	# more than 1 year ?
-	if interval.days > 363:
-		years, days = divmod(interval.days, 364)
+	if interval.days > 364:
+		years, days = divmod(interval.days, avg_days_per_gregorian_year)
 		leap_days, tmp = divmod(years, 4)
-		months, day = divmod((days + leap_days), 30.33)
+		days_left_without_leap_days = days - leap_days
+		months, day = divmod((days_left_without_leap_days), 30.33)
 		if int(months) == 0:
 			return "%s%s" % (int(years), _('interval_format_tag::years::y')[-1:])
 		return "%s%s %s%s" % (int(years), _('interval_format_tag::years::y')[-1:], int(months), _('interval_format_tag::months::m')[-1:])
@@ -752,24 +725,36 @@ def format_pregnancy_months(age):
 
 #---------------------------------------------------------------------------
 def is_leap_year(year):
+	if year < 1582:		# no leap years before Gregorian Reform
+		_log.debug('%s: before Gregorian Reform', year)
+		return False
+
 	# year is multiple of 4 ?
 	div, remainder = divmod(year, 4)
-	# no -> not a leap year
+	# * NOT divisible by 4
+	# -> common year
 	if remainder > 0:
 		return False
 
 	# year is a multiple of 100 ?
 	div, remainder = divmod(year, 100)
-	# no -> IS a leap year
+	# * divisible by 4
+	# * NOT divisible by 100
+	# -> leap year
 	if remainder > 0:
 		return True
 
 	# year is a multiple of 400 ?
 	div, remainder = divmod(year, 400)
-	# yes -> IS a leap year
+	# * divisible by 4
+	# * divisible by 100, so, perhaps not leaping ?
+	# * but ALSO divisible by 400
+	# -> leap year
 	if remainder == 0:
 		return True
 
+	# all others
+	# -> common year
 	return False
 
 #---------------------------------------------------------------------------
@@ -1552,22 +1537,6 @@ def str2pydt_matches(str2parse=None, patterns=None):
 	matches.extend(__single_char2py_dt(str2parse))
 	matches.extend(__explicit_offset2py_dt(str2parse))
 
-	# no more with Python3
-#	# try mxDT parsers
-#	try:
-#		date = mxDT.Parser.DateFromString (
-#			text = str2parse,
-#			formats = ('euro', 'iso', 'us', 'altus', 'altiso', 'lit', 'altlit', 'eurlit')
-#		)
-#		matches.append ({
-#			'data': mxdt2py_dt(date),
-#			'label': date.strftime('%Y-%m-%d')
-#		})
-#	except (ValueError, OverflowError):
-#		pass
-#	except mxDT.RangeError:
-#		pass
-
 	# apply explicit patterns
 	if patterns is None:
 		patterns = []
@@ -1590,12 +1559,27 @@ def str2pydt_matches(str2parse=None, patterns=None):
 
 	patterns.append('%Y.%m.%d')
 
+	parts = str2parse.split(maxsplit = 1)
+	hour = 11
+	minute = 11
+	second = 11
+	if len(parts) > 1:
+		for pattern in ['%H:%M', '%H:%M:%S']:
+			try:
+				date = pyDT.datetime.strptime(parts[1], pattern)
+				hour = date.hour
+				minute = date.minute
+				second = date.second
+				break
+			except ValueError:
+				# C-level overflow
+				continue
 	for pattern in patterns:
 		try:
-			date = pyDT.datetime.strptime(str2parse, pattern).replace (
-				hour = 11,
-				minute = 11,
-				second = 11,
+			date = pyDT.datetime.strptime(parts[0], pattern).replace (
+				hour = hour,
+				minute = minute,
+				second = second,
 				tzinfo = gmCurrentLocalTimezone
 			)
 			matches.append ({
@@ -1606,6 +1590,7 @@ def str2pydt_matches(str2parse=None, patterns=None):
 			# C-level overflow
 			continue
 
+
 	return matches
 
 #===========================================================================
@@ -1959,65 +1944,50 @@ def str2fuzzy_timestamp_matches(str2parse=None, default_time=None, patterns=None
 		} for m in __explicit_offset2py_dt(str2parse)
 	])
 
-	# reactivate, once mxDT becomes available on Py3k
-#	# try mxDT parsers
-#	try:
-#		# date ?
-#		date_only = mxDT.Parser.DateFromString (
-#			text = str2parse,
-#			formats = ('euro', 'iso', 'us', 'altus', 'altiso', 'lit', 'altlit', 'eurlit')
-#		)
-#		# time, too ?
-#		time_part = mxDT.Parser.TimeFromString(text = str2parse)
-#		datetime = date_only + time_part
-#		if datetime == date_only:
-#			accuracy = acc_days
-#			if isinstance(default_time, mxDT.DateTimeDeltaType):
-#				datetime = date_only + default_time
-#				accuracy = acc_minutes
-#		else:
-#			accuracy = acc_subseconds
-#		fts = cFuzzyTimestamp (
-#			timestamp = datetime,
-#			accuracy = accuracy
-#		)
-#		matches.append ({
-#			'data': fts,
-#			'label': fts.format_accurately()
-#		})
-#	except ValueError:
-#		pass
-#	except mxDT.RangeError:
-#		pass
-
 	if patterns is None:
 		patterns = []
 	patterns.extend([
-		['%Y-%m-%d', acc_days],
-		['%y-%m-%d', acc_days],
-		['%Y/%m/%d', acc_days],
-		['%y/%m/%d', acc_days],
-
-		['%d-%m-%Y', acc_days],
-		['%d-%m-%y', acc_days],
-		['%d/%m/%Y', acc_days],
-		['%d/%m/%y', acc_days],
-		['%d.%m.%Y', acc_days],
-
-		['%m-%d-%Y', acc_days],
-		['%m-%d-%y', acc_days],
-		['%m/%d/%Y', acc_days],
-		['%m/%d/%y', acc_days]
+		'%Y-%m-%d',
+		'%y-%m-%d',
+		'%Y/%m/%d',
+		'%y/%m/%d',
+		'%d-%m-%Y',
+		'%d-%m-%y',
+		'%d/%m/%Y',
+		'%d/%m/%y',
+		'%d.%m.%Y',
+		'%m-%d-%Y',
+		'%m-%d-%y',
+		'%m/%d/%Y',
+		'%m/%d/%y'
 	])
+
+	parts = str2parse.split(maxsplit = 1)
+	hour = 11
+	minute = 11
+	second = 11
+	acc = acc_days
+	if len(parts) > 1:
+		for pattern in ['%H:%M', '%H:%M:%S']:
+			try:
+				date = pyDT.datetime.strptime(parts[1], pattern)
+				hour = date.hour
+				minute = date.minute
+				second = date.second
+				acc = acc_minutes
+				break
+			except ValueError:
+				# C-level overflow
+				continue
 	for pattern in patterns:
 		try:
-			ts = pyDT.datetime.strptime(str2parse, pattern[0]).replace (
-				hour = 11,
-				minute = 11,
-				second = 11,
+			ts = pyDT.datetime.strptime(parts[0], pattern).replace (
+				hour = hour,
+				minute = minute,
+				second = second,
 				tzinfo = gmCurrentLocalTimezone
 			)
-			fts = cFuzzyTimestamp(timestamp = ts, accuracy = pattern[1])
+			fts = cFuzzyTimestamp(timestamp = ts, accuracy = acc)
 			matches.append ({
 				'data': fts,
 				'label': fts.format_accurately()
@@ -2025,7 +1995,6 @@ def str2fuzzy_timestamp_matches(str2parse=None, default_time=None, patterns=None
 		except ValueError:
 			# C-level overflow
 			continue
-
 	return matches
 
 #===========================================================================
@@ -2178,7 +2147,7 @@ if __name__ == '__main__':
 	#-----------------------------------------------------------------------
 	def test_format_interval():
 		intv = pyDT.timedelta(minutes=1, seconds=2)
-		for acc in _accuracy_strings.keys():
+		for acc in _accuracy_strings:
 			print ('[%s]: "%s" -> "%s"' % (acc, intv, format_interval(intv, acc)))
 		return
 
@@ -2187,7 +2156,7 @@ if __name__ == '__main__':
 			if intv is None:
 				print(tmp, '->', intv)
 				continue
-			for acc in _accuracy_strings.keys():
+			for acc in _accuracy_strings:
 				print ('[%s]: "%s" -> "%s"' % (acc, tmp, format_interval(intv, acc)))
 
 	#-----------------------------------------------------------------------
@@ -2250,10 +2219,9 @@ if __name__ == '__main__':
 			pyDT.timedelta(days = 366),
 			pyDT.timedelta(days = 367),
 			pyDT.timedelta(days = 400),
-			pyDT.timedelta(weeks = 52 * 30),
-			pyDT.timedelta(weeks = 52 * 79, days = 33)
+			pyDT.timedelta(weeks = 53 * 30),
+			pyDT.timedelta(weeks = 53 * 79, days = 33)
 		]
-
 		idx = 1
 		for intv in intervals:
 			print ('%s) %s -> %s' % (idx, intv, format_interval_medically(intv)))
@@ -2406,8 +2374,13 @@ if __name__ == '__main__':
 		print (pydt_strftime(dt, accuracy = acc_seconds))
 	#-------------------------------------------------
 	def test_is_leap_year():
-		for year in range(1995, 2017):
-			print (year, "leaps:", is_leap_year(year))
+		for idx in range(120):
+			year = 1993 + idx
+			tmp, offset = divmod(idx, 4)
+			if is_leap_year(year):
+				print (offset+1, '--', year, 'leaps')
+			else:
+				print (offset+1, '--', year)
 
 	#-------------------------------------------------
 	def test_get_date_of_weekday_in_week_of_date():
@@ -2435,7 +2408,7 @@ if __name__ == '__main__':
 	init()
 
 	#test_date_time()
-	#test_str2fuzzy_timestamp_matches()
+	test_str2fuzzy_timestamp_matches()
 	#test_get_date_of_weekday_in_week_of_date()
 	#test_cFuzzyTimeStamp()
 	#test_get_pydt()
