@@ -65,10 +65,10 @@ class cMatchProvider(object):
 		"""
 		# sanity check
 		if aFragment is None:
-			raise ValueError, 'Cannot find matches without a fragment.'
+			raise ValueError('Cannot find matches without a fragment.')
 
 		# user explicitly wants all matches
-		if aFragment == u'*':
+		if aFragment == '*':
 			return self.getAllMatches()
 
 		# case insensitivity
@@ -78,7 +78,7 @@ class cMatchProvider(object):
 			tmpFragment = self.__ignored_chars.sub('', tmpFragment)
 		# normalize word separators
 		if self.__word_separators is not None:
-			tmpFragment = u' '.join(self.__word_separators.split(tmpFragment))
+			tmpFragment = ' '.join(self.__word_separators.split(tmpFragment))
 		# length in number of significant characters only
 		lngFragment = len(tmpFragment)
 
@@ -189,7 +189,7 @@ class cMatchProvider_FixedList(cMatchProvider):
 	def __init__(self, aSeq = None):
 		"""aSeq must be a list of dicts. Each dict must have the keys (data, label, weight)
 		"""
-		if not type(aSeq) in [type(None), type([]), type(())]:
+		if not type(aSeq) in [type(None), list, tuple]:
 			_log.error('fixed list match provider argument must be a list/tuple of dicts/None')
 			raise TypeError('fixed list match provider argument must be a list/tuple of dicts/None')
 
@@ -234,7 +234,7 @@ class cMatchProvider_FixedList(cMatchProvider):
 			# found as a true substring
 			elif fragment_pos > 0:
 				# but use only if substring is at start of a word
-				if item_label[fragment_pos-1] == u' ':
+				if item_label[fragment_pos-1] == ' ':
 					matches.append(item)
 		# no matches found
 		if len(matches) == 0:
@@ -337,7 +337,7 @@ class cMatchProvider_Func(cMatchProvider):
 			# found as a true substring
 			# but use only if substring is at start of a word
 			# FIXME: use word seps
-			if (pos == 0) or (candidate['list_label'][pos-1] == u' '):
+			if (pos == 0) or (candidate['list_label'][pos-1] == ' '):
 				matches.append(candidate)
 		# no matches found
 		if len(matches) == 0:
@@ -446,6 +446,7 @@ class cMatchProvider_SQL2(cMatchProvider):
 		self._args = {}
 
 		self._SQL_data2match = None
+
 	#--------------------------------------------------------
 	# internal matching algorithms
 	#
@@ -457,31 +458,35 @@ class cMatchProvider_SQL2(cMatchProvider):
 	def getMatchesByPhrase(self, aFragment):
 		"""Return matches for aFragment at start of phrases."""
 
-		fragment_condition = u"ILIKE %(fragment)s"
-		self._args['fragment'] = u"%s%%" % aFragment
+		fragment_condition = "ILIKE %(fragment)s"
+		self._args['fragment'] = "%s%%" % aFragment
 
 		return self._find_matches(fragment_condition)
+
 	#--------------------------------------------------------
 	def getMatchesByWord(self, aFragment):
 		"""Return matches for aFragment at start of words inside phrases."""
 
-		fragment_condition = u"~* %(fragment)s"
+		fragment_condition = "~* %(fragment)s"
 		aFragment = gmPG2.sanitize_pg_regex(expression = aFragment, escape_all = False)
-		self._args['fragment'] = u"( %s)|(^%s)" % (aFragment, aFragment)
+		self._args['fragment'] = "( %s)|(^%s)" % (aFragment, aFragment)
 
 		return self._find_matches(fragment_condition)
+
 	#--------------------------------------------------------
 	def getMatchesBySubstr(self, aFragment):
 		"""Return matches for aFragment as a true substring."""
 
-		fragment_condition = u"ILIKE %(fragment)s"
-		self._args['fragment'] = u"%%%s%%" % aFragment
+		fragment_condition = "ILIKE %(fragment)s"
+		self._args['fragment'] = "%%%s%%" % aFragment
 
 		return self._find_matches(fragment_condition)
+
 	#--------------------------------------------------------
 	def getAllMatches(self):
 		"""Return all items."""
-		return self.getMatchesBySubstr(u'')
+		return self.getMatchesBySubstr('')
+
 	#--------------------------------------------------------
 	def get_match_by_data(self, data=None):
 		if self._SQL_data2match is None:
@@ -490,7 +495,7 @@ class cMatchProvider_SQL2(cMatchProvider):
 		query = {'cmd': self._SQL_data2match, 'args': {'pk': data}}
 		try:
 			rows, idx = gmPG2.run_ro_queries(queries = [query], get_col_idx = False)
-		except:
+		except Exception:
 			_log.exception('[%s]: error running _SQL_data2match, dropping query', self.__class__.__name__)
 			self._SQL_data2match = None
 			return None
@@ -501,11 +506,51 @@ class cMatchProvider_SQL2(cMatchProvider):
 
 		_log.error('[%s]: 0 or >1 rows found by running _SQL_data2match, ambiguous, ignoring', self.__class__.__name__)
 		return None
+
+	#--------------------------------------------------------
+	def _rows2matches(self, rows):
+		"""Turns retrieved database values into a list
+		   of dicts fit for phrasewheel use.
+
+		   This method can be overridden to massage arbitrary
+		   data into the proper list of dicts.
+		"""
+		matches = []
+		for row in rows:
+			# PRW wants a weight
+			match = {'weight': 0}
+			try:
+				match['data'] = row['data']
+			except KeyError:
+				match['data'] = row[0]
+			try:
+				match['list_label'] = row['list_label']
+			except KeyError:
+				match['list_label'] = row[1]
+			# explicit "field_label" in result ?
+			try:
+				match['field_label'] = row['field_label']
+			# no
+			except KeyError:
+				# but does row[2] exist ?
+				try:
+					match['field_label'] = row[2]
+				# no: reuse "list_label"
+				except IndexError:
+					match['field_label'] = match['list_label']
+			matches.append(match)
+
+		return matches
+
 	#--------------------------------------------------------
 	def _find_matches(self, fragment_condition):
+		"""Loads matching data from PostgreSQL and turns them into
+		   matches fit for consumption by a phrasewheel.
+		"""
 		if self.print_queries:
-			print "----------------------"
-			print pydt.datetime.now()
+			print("----------------------")
+			print(pydt.datetime.now())
+
 		matches = []
 		for query in self._queries:
 			where_fragments = {'fragment_condition': fragment_condition}
@@ -518,69 +563,35 @@ class cMatchProvider_SQL2(cMatchProvider):
 					# we do have a context value for this key, so add the where condition
 					where_fragments[context_key] = where_part
 					if self.print_queries:
-						print "ctxt ph:", placeholder
-						print "ctxt where:", where_part
-						print "ctxt val:", self._context_vals[placeholder]
+						print("ctxt ph:", placeholder)
+						print("ctxt where:", where_part)
+						print("ctxt val:", self._context_vals[placeholder])
 				except KeyError:
 					# we don't have a context value for this key, so skip the where condition
-					where_fragments[context_key] = u''
+					where_fragments[context_key] = ''
 					if self.print_queries:
-						print "invalid ctxt key:", context_key
+						print("invalid ctxt key:", context_key)
 
 			cmd = query % where_fragments
 
 			if self.print_queries:
-				print "class:", self.__class__.__name__
-				print "ctxt:", self._context_vals
-				print "args:", self._args
-				print "query:", cmd
+				print("class:", self.__class__.__name__)
+				print("ctxt:", self._context_vals)
+				print("args:", self._args)
+				print("query:", cmd)
 
 			try:
 				rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': self._args}], get_col_idx = False)
-			except:
+			except gmPG2.PG_ERROR_EXCEPTION:
 				_log.exception('[%s]: error running match provider SQL, dropping query', self.__class__.__name__)
 				idx = self._queries.index(query)
 				del self._queries[idx]
 				break
-
 			# no matches found: try next query
 			if len(rows) == 0:
 				continue
-
-			for row in rows:
-				match = {'weight': 0}
-
-				try:
-					match['data'] = row['data']
-				except KeyError:
-					match['data'] = row[0]
-
-				try:
-					match['list_label'] = row['list_label']
-				except KeyError:
-					match['list_label'] = row[1]
-
-				# explicit "field_label" in result ?
-				try:
-					match['field_label'] = row['field_label']
-				# no
-				except KeyError:
-					# but does row[2] exist ?
-					try:
-						match['field_label'] = row[2]
-					# no: reuse "list_label"
-					except IndexError:
-						match['field_label'] = match['list_label']
-
-#				try:
-#					match['label'] = row['label']
-#				except KeyError:
-#					match['label'] = match['list_label']
-
-				matches.append(match)
-
+			matches = self._rows2matches(rows)
 			return (True, matches)
-
 		# none found whatsoever
 		return (False, [])
 
