@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010, 2011  Rickard Lindberg, Roger Lindberg
+# Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018  Rickard Lindberg, Roger Lindberg
 #
 # This file is part of Timeline.
 #
@@ -32,7 +32,7 @@ Template for translator comments (should be before all body parts):
 def install(help_system):
 
     help_system.install_page(
-        id="contents",
+        page_id="contents",
         header=_("Help contents"),
         body=("""
 - **%s**
@@ -41,10 +41,15 @@ def install(help_system):
     - Help(why_not_timeline_in_my_language)
     - Help(week_numbers_sunday_week_start)
     - Help(multiple_users)
+    - Help(check_all_categories)
 - **%s**
     - Help(timeline)
+    - Help(era)
     - Help(events)
+    - Help(milestones)
     - Help(categories)
+    - Help(experimental_features)
+    - Help(event_containers)
 - **%s**
     - Help(create_event)
     - Help(edit_event)
@@ -53,12 +58,12 @@ def install(help_system):
     - Help(edit_categories)
     - Help(select_events)
     - Help(import_timeline)
+    - Help(undo_action)
 - **Help(contact)**
 """ % (_("Questions and answers"), _("Concepts"), _("Tasks"))))
 
-
     help_system.install_page(
-        id="where_is_save",
+        page_id="where_is_save",
         header=_("Where is the save button?"),
         # TRANSLATORS: This text uses special markup.
         # DON'T translate 'HelpFigure(..)' or 'Help(..)'.
@@ -69,9 +74,8 @@ def install(help_system):
 There is no save button. Timeline will automatically save your data whenever needed.
 """))
 
-
     help_system.install_page(
-        id="week_numbers_sunday_week_start",
+        page_id="week_numbers_sunday_week_start",
         header=_("Where do the week numbers go if I start my weeks on Sunday?"),
         # TRANSLATORS: This text uses special markup.
         # DON'T translate 'HelpFigure(..)' or 'Help(..)'.
@@ -83,7 +87,7 @@ The date data object used does not support week numbers for weeks that start on
 """))
 
     help_system.install_page(
-        id="multiple_users",
+        page_id="multiple_users",
         header=_("Can multiple users work with the same timeline?"),
         # TRANSLATORS: This text uses special markup.
         # DON'T translate 'HelpFigure(..)' or 'Help(..)'.
@@ -97,12 +101,29 @@ When you try to make a change and someone else has made a change you will be ask
 
 - Set timeline in read-only mode.
 - Synchronize the timeline.
- 
+
 During the your edit action the timeline is locked for changes by others. If you try to edit a timeline when it is locked by someone else you will be notified about this situation.
 """))
 
     help_system.install_page(
-        id="timeline",
+        page_id="check_all_categories",
+        header=_("Can I Check or Uncheck all categories?"),
+        related_pages=["categories", "edit_categories"],
+        # TRANSLATORS: This text uses special markup.
+        # DON'T translate 'HelpFigure(..)' or 'Help(..)'.
+        # Just write them as they are.
+        # Stars produce emphasized text. DON'T remove them.
+        # Dashes produce bullet lists. DON'T remove them.
+        body=_("""
+Yes you can check or uncheck all categories as well as a lot of other selection alternatives.
+
+Make sure the categories pane is visible and then right-click with the mouse in the pane.
+A context menu will now show up with all the check/uncheck alternatives available.
+
+"""))
+
+    help_system.install_page(
+        page_id="timeline",
         header=_("Timeline"),
         related_pages=["scrolling", "zooming", "import_timeline", "events", "categories", "contact"],
         # TRANSLATORS: This text uses special markup.
@@ -119,7 +140,7 @@ The timeline is divided in two areas with a horizontal adjustable divider line.
 """))
 
     help_system.install_page(
-        id="scrolling",
+        page_id="scrolling",
         header=_("Scrolling Timeline"),
         related_pages=["timeline"],
         # TRANSLATORS: This text uses special markup.
@@ -138,7 +159,7 @@ Events are scrolled towards or away from the divider line separating point- and
 """))
 
     help_system.install_page(
-        id="zooming",
+        page_id="zooming",
         header=_("Zooming Timeline"),
         related_pages=["timeline"],
         # TRANSLATORS: This text uses special markup.
@@ -155,9 +176,9 @@ To zoom vertically, hold down the Alt-key and scroll the mouse wheel.
 """))
 
     help_system.install_page(
-        id="events",
+        page_id="events",
         header=_("Events"),
-        related_pages=["event_properties", "create_event", "select_events", "edit_event", "delete_event", "move_event_vertically", "duplicate_event", "categories"],
+        related_pages=["event_properties", "add_icon", "create_event", "select_events", "edit_event", "delete_event", "move_event_vertically", "duplicate_event", "categories", "search_event"],
         # TRANSLATORS: This text uses special markup.
         # DON'T translate 'HelpFigure(..)' or 'Help(..)'.
         # Just write them as they are.
@@ -168,9 +189,24 @@ An event is the basic data type for representing information on the timeline.  I
 """))
 
     help_system.install_page(
-        id="event_properties",
+        page_id="era",
+        header=_("Era"),
+        related_pages=["timeline"],
+        # TRANSLATORS: This text uses special markup.
+        # DON'T translate 'HelpFigure(..)' or 'Help(..)'.
+        # Just write them as they are.
+        # Stars produce emphasized text. DON'T remove them.
+        # Dashes produce bullet lists. DON'T remove them.
+        body=_("""
+An Era is A clearly defined period of time of arbitrary but well-defined length.
+
+An Era is displayed as a background with the color defined for the Era. The Era name is written att the bottom of the timeline.
+"""))
+
+    help_system.install_page(
+        page_id="event_properties",
         header=_("Event Properties"),
-        related_pages=["events", "event_containers"],
+        related_pages=["events", "event_containers", "add_icon"],
         # TRANSLATORS: This text uses special markup.
         # DON'T translate 'HelpFigure(..)' or 'Help(..)'.
         # Just write them as they are.
@@ -190,11 +226,35 @@ For an event the following properties can be defined.
  - Description - Event description that is shown i the balloon.
  - Icon - Image icon shown in balloon.
  - Alert - An alert dialog is opened at the specified alert time.
- - Hyperlink - A hyperlink that can be reached in the event context menu.
+ - Hyperlinks - A list of hyperlink that can be reached in the event context menu.
 """))
 
     help_system.install_page(
-        id="categories",
+        page_id="milestones",
+        header=_("Milestones"),
+        related_pages=["events"],
+        # TRANSLATORS: This text uses special markup.
+        # DON'T translate 'HelpFigure(..)' or 'Help(..)'.
+        # Just write them as they are.
+        # Stars produce emphasized text. DON'T remove them.
+        # Dashes produce bullet lists. DON'T remove them.
+        body=_("""
+A milestone is a special case of a point event. It is rendered on the timescale of a timeline and it can have a desciption shown when hooverd over. It can also have a one character label that is displayed in the milestone box.
+
+A milestone ...
+
+* is created by selecting the menu alternative Timeline -> Create milestone.
+
+* is edited by doubleclicking on it.
+
+* is deleted by clicking on it and thereafter click the delete button.
+
+* can be dragged to a new position.
+"""))
+
+
+    help_system.install_page(
+        page_id="categories",
         header=_("Categories"),
         related_pages=["categories_delete", "events"],
         # TRANSLATORS: This text uses special markup.
@@ -207,7 +267,25 @@ Categories are used to group events. An event can only belong to one category. A
 """))
 
     help_system.install_page(
-        id="create_event",
+        page_id="experimental_features",
+        header=_("Experimental Features"),
+        # TRANSLATORS: This text uses special markup.
+        # DON'T translate 'HelpFigure(..)' or 'Help(..)'.
+        # Just write them as they are.
+        # Stars produce emphasized text. DON'T remove them.
+        # Dashes produce bullet lists. DON'T remove them.
+        body=_("""
+Experimental features are features implemented in Timeline but not yet decided to be permanent.
+
+An experimental feature can be switched on or off in the preferences dialog.
+
+The functionality in these features may not be fully implemented and may not have been as extensively tested as the rest of the application.
+
+The users feedback can be important when the decision to make the features permanent or not, is taken.
+"""))
+
+    help_system.install_page(
+        page_id="create_event",
         header=_("Create event"),
         related_pages=["events", "delete_event"],
         # TRANSLATORS: This text uses special markup.
@@ -224,7 +302,34 @@ The *Create Event* dialog can be opened in the following ways:
 """))
 
     help_system.install_page(
-        id="edit_event",
+        page_id="undo_action",
+        header=_("Undo/Redo"),
+        related_pages=["create_event", "edit_event", "delete_event", "edit_categories"],
+        # TRANSLATORS: This text uses special markup.
+        # DON'T translate 'HelpFigure(..)' or 'Help(..)'.
+        # Just write them as they are.
+        # Stars produce emphasized text. DON'T remove them.
+        # Dashes produce bullet lists. DON'T remove them.
+        body=_("""
+The *Undo* function can revert an action such as creating an event, editing a category or deleting an event.
+
+To revert an action you:
+
+- Use the Ctrl+Z key (Key combination can be changed by user)
+- Select the menu *Timeline* - *Undo*
+
+To save memory usage we have decided to limit the number of actions that can be reverted.
+This means that only the 10 latest actions can be Undone.
+
+An action that is Undone can also be Redone if you:
+
+- Use the Alt+Z key (Key combination can be changed by user)
+- Select the menu *Timeline* - *Redo*
+
+"""))
+
+    help_system.install_page(
+        page_id="edit_event",
         header=_("Edit event"),
         related_pages=["events", "select_events"],
         # TRANSLATORS: This text uses special markup.
@@ -234,10 +339,12 @@ The *Create Event* dialog can be opened in the following ways:
         # Dashes produce bullet lists. DON'T remove them.
         body=_("""
 The *Edit Event* dialog can be opened by double clicking on an event or by selecting one event and select the 'Timeline -> Edit Selected Event...' menu.
+
+An image icon can be associated with an event by dragging the image file and dropping it on an event.
 """))
 
     help_system.install_page(
-        id="move_event_vertically",
+        page_id="move_event_vertically",
         header=_("Move event vertically"),
         related_pages=["events", "select_events"],
         # TRANSLATORS: This text uses special markup.
@@ -246,11 +353,11 @@ The *Edit Event* dialog can be opened by double clicking on an event or by selec
         # Stars produce emphasized text. DON'T remove them.
         # Dashes produce bullet lists. DON'T remove them.
         body=_("""
-An event can be moved vertically. This is done by first selecting the event and therefter using the Alt+Up or Alt+Down keys.
+An event can be moved vertically. This is done by first selecting the event and thereafter using the Up or Down keys.
 """))
 
     help_system.install_page(
-        id="duplicate_event",
+        page_id="duplicate_event",
         header=_("Duplicate event"),
         related_pages=["events", "select_events"],
         # TRANSLATORS: This text uses special markup.
@@ -266,14 +373,37 @@ Now a dialog appears in which you can define
  - The time period used
  - The frequency of time periods
  - The direction
- 
+
  If number of duplications = 3, time span = day and frequency = 2, you will get 3 new copies of the event spread out with the time span of 2 days between them.
- 
+
  You can also get to the duplication dialog from the event context menu, wich appears if you right-click an event with the mouse.
 """))
 
     help_system.install_page(
-        id="select_events",
+        page_id="search_event",
+        header=_("Search event"),
+        related_pages=["events", ],
+        # TRANSLATORS: This text uses special markup.
+        # DON'T translate 'HelpFigure(..)' or 'Help(..)'.
+        # Just write them as they are.
+        # Stars produce emphasized text. DON'T remove them.
+        # Dashes produce bullet lists. DON'T remove them.
+        body=_("""
+You can search for an event by selecting the Edit -> Search menu.
+
+A text control is opened in the lower left corner of the application.
+
+Enter a target text in the text control and click Enter.
+If the text is found in the Text or Description of any event, the first event
+found is highlighted for a short period of time.
+
+By clicking on the icons to the right of the text control you can navigate
+back and forth between all the events that has been found. You can also
+select an event from a list of all found events.
+"""))
+
+    help_system.install_page(
+        page_id="select_events",
         header=_("Selecting events"),
         # TRANSLATORS: This text uses special markup.
         # DON'T translate 'HelpFigure(..)' or 'Help(..)'.
@@ -285,7 +415,7 @@ To select an event, click on it. To select multiple events, hold down the *Ctrl*
 """))
 
     help_system.install_page(
-        id="import_timeline",
+        page_id="import_timeline",
         header=_("Import timeline"),
         related_pages=["timeline"],
         # TRANSLATORS: This text uses special markup.
@@ -300,8 +430,9 @@ First open a timeline and then select menu 'File -> Import timeline...' and sele
 """))
 
     help_system.install_page(
-        id="event_containers",
+        page_id="event_containers",
         header=_("Event Containers"),
+        related_pages=["events", "experimental_features"],
         # TRANSLATORS: This text uses special markup.
         # DON'T translate 'HelpFigure(..)' or 'Help(..)'.
         # Just write them as they are.
@@ -312,13 +443,16 @@ Containers are a way to group events together.
 In a container events can not overlap, so if you add a new event to a container
 all other events are moved to give room for the new event. The same thing happens
 if you resize an event within the container.
-             
-Have a look at this video for a demo. 
+
+Have a look at this video for a demo.
     <http://www.youtube.com/watch?v=dBwEQ3vqB_I>
+
+From version 1.8 there is a second container strategy that let's events overlap in time within the container.
+This strategy is implemented as an experimental feature and can be selected in the preferences dialog.
 """))
 
     help_system.install_page(
-        id="delete_event",
+        page_id="delete_event",
         header=_("Delete event"),
         related_pages=["events", "select_events"],
         # TRANSLATORS: This text uses special markup.
@@ -331,7 +465,7 @@ To delete an event, select it and press the *Del* key. Multiple events can be de
 """))
 
     help_system.install_page(
-        id="categories_delete",
+        page_id="categories_delete",
         header=_("Will associated events be deleted when I delete a category?"),
         # TRANSLATORS: This text uses special markup.
         # DON'T translate 'HelpFigure(..)' or 'Help(..)'.
@@ -343,7 +477,30 @@ No. The events will still be there but they will not belong to a category.
 """))
 
     help_system.install_page(
-        id="edit_categories",
+        page_id="add_icon",
+        header=_("Add a user defined icon"),
+        related_pages=["event_properties"],
+        # TRANSLATORS: This text uses special markup.
+        # DON'T translate 'HelpFigure(..)' or 'Help(..)'.
+        # Just write them as they are.
+        # Stars produce emphasized text. DON'T remove them.
+        # Dashes produce bullet lists. DON'T remove them.
+        body=_("""
+Icons used for the event properties
+
+ - Fuzzy
+ - Locked
+ - Hyperlink
+
+can be user defined.
+
+To use an icon of your own you create a png image file and place it in
+the subdirectory icons/event_icons.
+Now the icon can be selected in the properties dialog on the Icons tab.
+"""))
+
+    help_system.install_page(
+        page_id="edit_categories",
         header=_("Edit categories"),
         related_pages=["categories"],
         # TRANSLATORS: This text uses special markup.
@@ -358,7 +515,7 @@ The visibility of categories can also be edited in the sidebar (*View* > *Sideba
 """))
 
     help_system.install_page(
-        id="contact",
+        page_id="contact",
         header=_("Contact"),
         # TRANSLATORS: This text uses special markup.
         # DON'T translate 'HelpFigure(..)' or 'Help(..)'.
@@ -370,7 +527,7 @@ If you have more questions about Timeline, or if you want to get in contact with
 """))
 
     help_system.install_page(
-        id="why_not_timeline_in_my_language",
+        page_id="why_not_timeline_in_my_language",
         header=_("Why is Timeline not available in my language?"),
         related_pages=["contact"],
         # TRANSLATORS: This text uses special markup.
