@@ -16,7 +16,19 @@
 # along with Timeline.  If not, see <http://www.gnu.org/licenses/>.
 
 
-class DrawingAreaProxy():
+class DrawingAreaProxy:
+    """
+    The purpose of this proxy is to simplify the access to the canvas
+    from the MainFrame window.
+    
+    Example of usage in MainFrame GuiCreator:
+        def zoomout(evt):
+            DrawingAreaProxy(self).zoom_out()
+            
+    Instead of writing:
+        def zoomout(evt):
+            self.main_panel.timeline_panel.timeline_canvas.zoom_out()
+    """
 
     def __init__(self, creator):
         from timelinelib.wxgui.frames.mainframe.mainframe import MainFrame
@@ -29,8 +41,12 @@ class DrawingAreaProxy():
     def zoom_out(self):
         self.timeline_canvas.zoom_out()
 
-    def VertZoomIn(self):
-        self.timeline_canvas.VertZoomIn()
+    def vertical_zoom_in(self):
+        self.timeline_canvas.vertical_zoom_in()
 
-    def VertZoomOut(self):
-        self.timeline_canvas.VertZoomOut()
+    def vertical_zoom_out(self):
+        self.timeline_canvas.vertical_zoom_out()
+
+    @property
+    def view_properties(self):
+        return self.timeline_canvas.view_properties
\ No newline at end of file
