@@ -1388,11 +1388,9 @@ class cCurrentSubstancesGrid(wx.grid.Grid):
 	#------------------------------------------------------------
 	def get_selected_rows(self):
 		rows = {}
-
 		for row, col in self.get_selected_cells():
 			rows[row] = True
-
-		return rows.keys()
+		return list(rows)
 
 	#------------------------------------------------------------
 	def get_selected_data(self):
@@ -1941,7 +1939,7 @@ def configure_default_medications_lab_panel(parent=None):
 	)
 
 #============================================================
-def configure_adr_url(self):
+def configure_adr_url():
 
 	def is_valid(value):
 		value = value.strip()
