@@ -50,6 +50,6 @@ class gmMeasurementsGridPlugin(gmPlugin.cNotebookPlugin):
 # main
 #----------------------------------------------------------------------
 if __name__ == "__main__":
-	print "no test code"
+	print("no test code")
 
 #======================================================================
